@@ -1,7 +1,7 @@
 //
 //    Creating and closing a file.
 
-package intro;
+package examples.intro;
 
 import ncsa.hdf.hdf5lib.H5;
 import ncsa.hdf.hdf5lib.HDF5Constants;
