@@ -1,13 +1,15 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * National Comptational Science Alliance                                   *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf-java/COPYING file.                                                   *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF Java Products. The full HDF Java copyright       *
+ * notice, including terms governing use, modification, and redistribution,  *
+ * is contained in the file, COPYING.  COPYING can be found at the root of   *
+ * the source code distribution tree. You can also access it online  at      *
+ * http://www.hdfgroup.org/products/licenses.html.  If you do not have       *
+ * access to the file, you may request a copy from help@hdfgroup.org.        *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
  *  This code is the C-interface called by Java programs to access the
@@ -17,7 +19,7 @@
  *  analogous arguments and return codes.
  *
  *  For details of the HDF libraries, see the HDF Documentation at:
- *   http://hdf.ncsa.uiuc.edu/HDF5/doc/
+ *    http://hdfdfgroup.org/HDF5/doc/
  *
  */
 
@@ -25,11 +27,14 @@
 extern "C" {
 #endif
 
-#include "hdf5.h"
-#include "h5util.h"
 #include <jni.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include "hdf5.h"
+#include "h5jni.h"
+#include "h5gImp.h"
+#include "h5util.h"
 
 /* missing definitions from hdf5.h */
 #ifndef FALSE
@@ -41,43 +46,35 @@ extern "C" {
 #endif
 
 #ifdef __cplusplus
-#define ENVPTR (env)
-#define ENVPAR 
+    herr_t obj_info_all(hid_t g_id, const char *name, const H5L_info_t *linfo, void *op_data);
+    herr_t obj_info_max(hid_t g_id, const char *name, const H5L_info_t *linfo, void *op_data);
+  int H5Gget_obj_info_all(hid_t, char **, int *, int *, unsigned long *, unsigned long *, int);
+    int H5Gget_obj_info_max(hid_t, char **, int *, int *, unsigned long *, int);
 #else
-#define ENVPTR (*env)
-#define ENVPAR env,
+    static herr_t obj_info_all(hid_t g_id, const char *name, const H5L_info_t *linfo, void *op_data);
+    static herr_t obj_info_max(hid_t g_id, const char *name, const H5L_info_t *linfo, void *op_data);
+  static int H5Gget_obj_info_all(hid_t, char **, int *, int *, unsigned long *, unsigned long *, int);
+    static int H5Gget_obj_info_max(hid_t, char **, int *, int *, unsigned long *, int);
 #endif
 
-#ifdef __cplusplus
-herr_t obj_info_all(hid_t loc_id, const char *name, void *opdata);
-herr_t H5Gget_obj_info_all(hid_t, char *, char **, int *, unsigned long *);
-#else
-static herr_t obj_info_all(hid_t loc_id, const char *name, void *opdata);
-static herr_t H5Gget_obj_info_all(hid_t, char *, char **, int *, unsigned long *);
-#endif
-
-extern jboolean h5outOfMemory( JNIEnv *env, char *functName);
-extern jboolean h5JNIFatalError( JNIEnv *env, char *functName);
-extern jboolean h5nullArgument( JNIEnv *env, char *functName);
-extern jboolean h5libraryError( JNIEnv *env );
-extern jboolean h5badArgument( JNIEnv *env, char *functName);
-
-
 typedef struct info_all
 {
     char **objname;
-    int *type;
+    int *otype;
+    int *ltype;
     unsigned long *objno;
+    unsigned long *fno;
+    unsigned long idxnum;
     int count;
 } info_all_t;
 
 /*
  * Class:     ncsa_hdf_hdf5lib_H5
- * Method:    H5Gcreate
- * Signature: (ILjava/lang/String;I)I
+ * Method:    _H5Gcreate
+ * Signature: (ILjava/lang/String;J)I
  */
 JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5__1H5Gcreate
-  (JNIEnv *env, jclass clss, jint loc_id, jstring name, jint size_hint)
+  (JNIEnv *env, jclass clss, jint loc_id, jstring name, jlong size_hint)
 {
     hid_t status;
     char* gName;
@@ -95,7 +92,7 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5__1H5Gcreate
         return -1;
     }
 
-    status = H5Gcreate((hid_t)loc_id, gName, (size_t)size_hint );
+    status = H5Gcreate2((hid_t)loc_id, gName, (hid_t)H5P_DEFAULT, (hid_t)H5P_DEFAULT, (hid_t)H5P_DEFAULT );
 
     ENVPTR->ReleaseStringUTFChars(ENVPAR name,gName);
     if (status < 0) {
@@ -106,7 +103,7 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5__1H5Gcreate
 
 /*
  * Class:     ncsa_hdf_hdf5lib_H5
- * Method:    H5Gopen
+ * Method:    _H5Gopen
  * Signature: (ILjava/lang/String;)I
  */
 JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5__1H5Gopen
@@ -128,7 +125,7 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5__1H5Gopen
         return -1;
     }
 
-    status = H5Gopen((hid_t)loc_id, gName );
+    status = H5Gopen2((hid_t)loc_id, gName, (hid_t)H5P_DEFAULT );
 
     ENVPTR->ReleaseStringUTFChars(ENVPAR name,gName);
     if (status < 0) {
@@ -139,16 +136,13 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5__1H5Gopen
 
 /*
  * Class:     ncsa_hdf_hdf5lib_H5
- * Method:    H5Gclose
+ * Method:    _H5Gclose
  * Signature: (I)I
  */
 JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5__1H5Gclose
   (JNIEnv *env, jclass clss, jint group_id)
 {
-    herr_t retVal = 0;
-
-    if (group_id > 0)
-        retVal =  H5Gclose((hid_t)group_id) ;
+    herr_t retVal =  H5Gclose((hid_t)group_id) ;
 
     if (retVal < 0) {
         h5libraryError(env);
@@ -204,11 +198,11 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Glink
 /*
  * Class:     ncsa_hdf_hdf5lib_H5
  * Method:    H5Glink
- * Signature: (IILjava/lang/String;Ljava/lang/String;)I
+ * Signature: (ILjava/lang/String;IILjava/lang/String;)I
  */
 JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Glink2
-  (JNIEnv *env, jclass clss, 
-    jint current_loc_id, jstring current_name, jint link_type, 
+  (JNIEnv *env, jclass clss,
+    jint current_loc_id, jstring current_name, jint link_type,
     jint new_loc_id, jstring new_name)
 {
     herr_t status;
@@ -325,7 +319,7 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gmove
 /*
  * Class:     ncsa_hdf_hdf5lib_H5
  * Method:    H5Gget_objinfo
- * Signature: (ILjava/lang/String;Z[J[I)I
+ * Signature: (ILjava/lang/String;Z[J[J[I[J)I
  */
 JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1objinfo
   (JNIEnv *env, jclass clss, jint loc_id, jstring name, jboolean follow_link,
@@ -345,9 +339,11 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1objinfo
     }
     if (follow_link == JNI_TRUE) {
         follow = TRUE;  /*  HDF5 'TRUE' */
-    } else if (follow_link == JNI_FALSE) {
+    }
+    else if (follow_link == JNI_FALSE) {
         follow = FALSE;  /*  HDF5 'FALSE' */
-    } else {
+    }
+    else {
         h5badArgument( env, "H5Gget_objinfo:  follow_link is invalid");
         return -1;
     }
@@ -425,7 +421,9 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1objinfo
         ENVPTR->ReleaseIntArrayElements(ENVPAR link_info,linkInfo,JNI_ABORT);
         ENVPTR->ReleaseStringUTFChars(ENVPAR name,gName);
         h5libraryError(env);
-    } else {
+        return -1;
+    }
+    else {
         fileInfo[0] = (jlong)h5gInfo.fileno[0];
         fileInfo[1] = (jlong)h5gInfo.fileno[1];
         objInfo[0] = (jlong)h5gInfo.objno[0];
@@ -449,7 +447,8 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1objinfo
  * Signature: (ILjava/lang/String;I[Ljava/lang/String;)I
  */
 JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1linkval
-  (JNIEnv *env, jclass clss, jint loc_id, jstring name, jint size, jobjectArray value)
+  (JNIEnv *env, jclass clss, jint loc_id, jstring name, jint size,
+          jobjectArray value)
 {
     char* gName;
     jboolean isCopy;
@@ -493,7 +492,8 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1linkval
         /*  the SetObjectArrayElement may raise exceptions... */
         ENVPTR->SetObjectArrayElement(ENVPAR value,0,(jobject)str);
         free(lValue);
-    } else {
+    }
+    else {
         free(lValue);
         h5libraryError(env);
     }
@@ -598,7 +598,8 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1comment
         /*  The SetObjectArrayElement may raise exceptions */
         ENVPTR->SetObjectArrayElement(ENVPAR comment,0,(jobject)str);
         free(gComment);
-    } else {
+    }
+    else {
         free(gComment);
         h5libraryError(env);
     }
@@ -608,13 +609,13 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1comment
 
 
 /***************************************************************
- *                   New APIs for HDF5.1.6                     *
+ *                   New APIs for HDF5.1.8                    *
  ***************************************************************/
 
 /*
  * Class:     ncsa_hdf_hdf5lib_H5
  * Method:    H5Gget_num_objs
- * Signature: (I[J[J)I
+ * Signature: (I[J)I
  */
 JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1num_1objs
   (JNIEnv *env, jclass clss, jint loc_id, jlongArray num_obj)
@@ -652,11 +653,10 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1num_1objs
         h5libraryError(env);
         return -1;
     }
-
     for (i = 0; i < rank; i++) {
-        num_objP[i] = num_obja[i];
-    }
-    ENVPTR->ReleaseLongArrayElements(ENVPAR num_obj,num_objP,0);
+            num_objP[i] = num_obja[i];
+        }
+        ENVPTR->ReleaseLongArrayElements(ENVPAR num_obj,num_objP,0);
 
     free(num_obja);
     return (jint)status;
@@ -664,11 +664,12 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1num_1objs
 
 /*
  * Class:     ncsa_hdf_hdf5lib_H5
- * Method:    H5Gget_objname_by_idx(hid_t group_id, hsize_t idx, char *name, size_t* size )
- * Signature: (IJLjava/lang/String;)J
+ * Method:    H5Gget_objname_by_idx
+ * Signature: (IJ[Ljava/lang/String;J)J
  */
 JNIEXPORT jlong JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1objname_1by_1idx
-  (JNIEnv *env, jclass clss, jint group_id, jlong idx, jobjectArray name, jlong buf_size)
+  (JNIEnv *env, jclass clss, jint group_id, jlong idx,
+          jobjectArray name, jlong buf_size)
 {
     char *aName;
     jstring str;
@@ -689,10 +690,9 @@ JNIEXPORT jlong JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1objname_1by_1idx
     if (size < 0) {
         free(aName);
         h5libraryError(env);
-        return -1;
         /*  exception, returns immediately */
+        return -1;
     }
-
     /* successful return -- save the string; */
     str = ENVPTR->NewStringUTF(ENVPAR aName);
     if (str == NULL) {
@@ -700,7 +700,6 @@ JNIEXPORT jlong JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1objname_1by_1idx
         h5JNIFatalError( env,"H5Gget_objname_by_idx:  return string failed");
         return -1;
     }
-
     free(aName);
     /*  Note: throws ArrayIndexOutOfBoundsException,
         ArrayStoreException */
@@ -712,8 +711,8 @@ JNIEXPORT jlong JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1objname_1by_1idx
 
 /*
  * Class:     ncsa_hdf_hdf5lib_H5
- * Method:    H5Gget_objtype_by_idx(hid_t group_id, hsize_t idx )
- * Signature: (IJLjava/lang/String;)J
+ * Method:    H5Gget_objtype_by_idx
+ * Signature: (IJ)I
  */
 JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1objtype_1by_1idx
   (JNIEnv *env, jclass clss, jint group_id, jlong idx)
@@ -724,6 +723,7 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1objtype_1by_1idx
     if (type < 0) {
         h5libraryError(env);
         /*  exception, returns immediately */
+        return -1;
     }
 
     return (jint)type;
@@ -742,80 +742,108 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1objtype_1by_1idx
 
 /*
  * Class:     ncsa_hdf_hdf5lib_H5
- * Method:    H5Gget_obj_info_idx
- * Signature: (ILjava/lang/String;I[I[Ljava/lang/String;)I
+ * Method:    H5Gget_obj_info_all
+ * Signature: (ILjava/lang/String;[Ljava/lang/String;[I[I[J[JII)I
  */
 JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1obj_1info_1all
   (JNIEnv *env, jclass clss, jint loc_id, jstring group_name,
-    jobjectArray objName, jintArray oType, jlongArray oRef, jint n)
+  jobjectArray objName, jintArray oType, jintArray lType, jlongArray fNo,
+  jlongArray oRef, jint n, jint indx_type)
 {
-    herr_t status;
+    herr_t ret_val = -1;
     char *gName=NULL;
     char **oName=NULL;
     jboolean isCopy;
     jstring str;
-    jint *tarr;
+    jint *otarr;
+    jint *ltarr;
     jlong *refP;
-    unsigned long *refs;
+    jlong *fnoP;
+    unsigned long *refs=NULL;
+    unsigned long *fnos=NULL;
     int i;
+    int gid = loc_id;
+    int indexType = indx_type;
 
-    if (group_name == NULL) {
-        h5nullArgument( env, "H5Gget_obj_info_all:  group_name is NULL");
-        return -1;
+    if (group_name != NULL) {
+        gName = (char *)ENVPTR->GetStringUTFChars(ENVPAR group_name,&isCopy);
+        if (gName == NULL) {
+            h5JNIFatalError( env, "H5Gget_obj_info_all:  name not pinned");
+            return -1;
+        }
+        gid = H5Gopen2(loc_id, gName, H5P_DEFAULT);
+
+        ENVPTR->ReleaseStringUTFChars(ENVPAR group_name,gName);
+
+        if(gid < 0) {
+            h5JNIFatalError( env, "H5Gget_obj_info_all: could not get group identifier");
+            return -1;
+        }
     }
-    
+
     if (oType == NULL) {
         h5nullArgument( env, "H5Gget_obj_info_all:  oType is NULL");
         return -1;
     }
-    
+
+    if (lType == NULL) {
+        h5nullArgument( env, "H5Gget_obj_info_all:  lType is NULL");
+        return -1;
+    }
+
     if (oRef == NULL) {
         h5nullArgument( env, "H5Gget_obj_info_all:  oRef is NULL");
         return -1;
     }
 
-    gName = (char *)ENVPTR->GetStringUTFChars(ENVPAR group_name,&isCopy);
-    if (gName == NULL) {
-        h5JNIFatalError( env, "H5Gget_obj_info_all:  group_name not pinned");
+    otarr = ENVPTR->GetIntArrayElements(ENVPAR oType,&isCopy);
+    if (otarr == NULL) {
+        h5JNIFatalError( env, "H5Gget_obj_info_all:  otype not pinned");
         return -1;
     }
 
-    tarr = ENVPTR->GetIntArrayElements(ENVPAR oType,&isCopy);
-    if (tarr == NULL) {
-        ENVPTR->ReleaseStringUTFChars(ENVPAR group_name,gName);
+    ltarr = ENVPTR->GetIntArrayElements(ENVPAR lType,&isCopy);
+    if (ltarr == NULL) {
+        ENVPTR->ReleaseIntArrayElements(ENVPAR oType,otarr,JNI_ABORT);
+        h5JNIFatalError( env, "H5Gget_obj_info_all:  ltype not pinned");
+        return -1;
+    }
+
+    refP = ENVPTR->GetLongArrayElements(ENVPAR oRef,&isCopy);
+    fnoP = ENVPTR->GetLongArrayElements(ENVPAR fNo,&isCopy);
+    if (refP == NULL) {
+        ENVPTR->ReleaseIntArrayElements(ENVPAR lType,ltarr,JNI_ABORT);
+        ENVPTR->ReleaseIntArrayElements(ENVPAR oType,otarr,JNI_ABORT);
         h5JNIFatalError( env, "H5Gget_obj_info_all:  type not pinned");
         return -1;
     }
-    
-    refP = ENVPTR->GetLongArrayElements(ENVPAR oRef,&isCopy);
-    if (refP == NULL) {
-        ENVPTR->ReleaseStringUTFChars(ENVPAR group_name,gName);
-        ENVPTR->ReleaseIntArrayElements(ENVPAR oType,tarr,JNI_ABORT);
-        h5JNIFatalError( env, "H5Gget_obj_info_all:  type not pinned");
-        return -1;
-    }    
 
     oName = (char **)calloc(n, sizeof (*oName));
-    refs = (unsigned long *)malloc(n * sizeof (unsigned long));
-    
-    status = H5Gget_obj_info_all( (hid_t) loc_id, gName,  oName, (int *)tarr, refs);
+    if (!oName)
+      goto error;
 
-    ENVPTR->ReleaseStringUTFChars(ENVPAR group_name,gName);
-    if (status < 0) {
-        ENVPTR->ReleaseIntArrayElements(ENVPAR oType,tarr,JNI_ABORT);
-        ENVPTR->ReleaseLongArrayElements(ENVPAR oRef,refP,JNI_ABORT);
-        h5str_array_free(oName, n);
-        free(refs);
-        h5libraryError(env);
-        return -1;
-    } 
+    refs = (unsigned long *)calloc(n, sizeof (unsigned long));
+    fnos = (unsigned long *)calloc(n, sizeof (unsigned long));
+    if (!refs || !fnos)
+      goto error;
+
+    ret_val = H5Gget_obj_info_all( (hid_t) gid, oName, (int *)otarr, (int *)ltarr, fnos, refs, indexType);
+
+    if (ret_val < 0)
+        goto error;
 
     if (refs) {
         for (i=0; i<n; i++) {
             refP[i] = (jlong) refs[i];
         }
     }
-        
+
+    if (fnos) {
+        for (i=0; i<n; i++) {
+            fnoP[i] = (jlong) fnos[i];
+        }
+    }
+
     if (oName) {
         for (i=0; i<n; i++) {
             if (*(oName+i)) {
@@ -825,54 +853,482 @@ JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1obj_1info_1all
         } /* for (i=0; i<n; i++)*/
     }
 
-    free(refs);
-    h5str_array_free(oName, n);
-    ENVPTR->ReleaseIntArrayElements(ENVPAR oType,tarr,0);
-    ENVPTR->ReleaseLongArrayElements(ENVPAR oRef,refP,0);
-    
-    return (jint)status;
+    if (group_name != NULL) H5Gclose(gid);
+  ENVPTR->ReleaseIntArrayElements(ENVPAR lType,ltarr,0);
+  ENVPTR->ReleaseIntArrayElements(ENVPAR oType,otarr,0);
+  ENVPTR->ReleaseLongArrayElements(ENVPAR oRef,refP,0);
+  ENVPTR->ReleaseLongArrayElements(ENVPAR fNo,fnoP,0);
+  if (oName) h5str_array_free(oName, n);
+  if (refs) free(refs);
+  if (fnos) free(fnos);
+
+   return ret_val;
+
+error:
+  if (group_name != NULL) H5Gclose(gid);
+  ENVPTR->ReleaseIntArrayElements(ENVPAR lType,ltarr,JNI_ABORT);
+  ENVPTR->ReleaseIntArrayElements(ENVPAR oType,otarr,JNI_ABORT);
+  ENVPTR->ReleaseLongArrayElements(ENVPAR oRef,refP,JNI_ABORT);
+  ENVPTR->ReleaseLongArrayElements(ENVPAR fNo,fnoP,JNI_ABORT);
+  if (oName) h5str_array_free(oName, n);
+  if (refs) free(refs);
+  if (fnos) free(fnos);
+  h5libraryError(env);
+
+  return -1;
 }
 
-herr_t H5Gget_obj_info_all( hid_t loc_id, char *group_name, char **objname, int *type, unsigned long *objno)
+/*
+ * Class:     ncsa_hdf_hdf5lib_H5
+ * Method:    H5Gget_obj_info_max
+ * Signature: (I[Ljava/lang/String;[I[I[JII)I
+ */
+JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1obj_1info_1max
+  (JNIEnv *env, jclass clss, jint loc_id, jobjectArray objName,
+          jintArray oType, jintArray lType, jlongArray oRef,
+          int maxnum, int n)
 {
-    herr_t retVal = 0;
+    herr_t ret_val = -1;
+    char **oName=NULL;
+    jboolean isCopy;
+    jstring str;
+    jint *otarr;
+    jint *ltarr;
+    jlong *refP;
+    unsigned long *refs;
+    int i;
 
+    if (oType == NULL) {
+        h5nullArgument( env, "H5Gget_obj_info_max:  oType is NULL");
+        return -1;
+    }
+
+    if (lType == NULL) {
+        h5nullArgument( env, "H5Gget_obj_info_max:  lType is NULL");
+        return -1;
+    }
+
+    if (oRef == NULL) {
+        h5nullArgument( env, "H5Gget_obj_info_all:  oRef is NULL");
+        return -1;
+    }
+
+    otarr = ENVPTR->GetIntArrayElements(ENVPAR oType,&isCopy);
+    if (otarr == NULL) {
+        h5JNIFatalError( env, "H5Gget_obj_info_max:  otype not pinned");
+        return -1;
+    }
+
+    ltarr = ENVPTR->GetIntArrayElements(ENVPAR lType,&isCopy);
+    if (ltarr == NULL) {
+        ENVPTR->ReleaseIntArrayElements(ENVPAR oType,otarr,JNI_ABORT);
+        h5JNIFatalError( env, "H5Gget_obj_info_max:  ltype not pinned");
+        return -1;
+    }
+
+    refP = ENVPTR->GetLongArrayElements(ENVPAR oRef,&isCopy);
+    if (refP == NULL) {
+        ENVPTR->ReleaseIntArrayElements(ENVPAR oType,otarr,JNI_ABORT);
+        ENVPTR->ReleaseIntArrayElements(ENVPAR lType,ltarr,JNI_ABORT);
+        h5JNIFatalError( env, "H5Gget_obj_info_all:  type not pinned");
+        return -1;
+    }
+
+    oName = (char **)calloc(n, sizeof (*oName));
+    refs = (unsigned long *)calloc(n, sizeof (unsigned long));
+
+    ret_val = H5Gget_obj_info_max( (hid_t) loc_id, oName, (int *)otarr, (int *)ltarr, refs, maxnum );
+
+    if (ret_val < 0) {
+        ENVPTR->ReleaseIntArrayElements(ENVPAR lType,ltarr,JNI_ABORT);
+        ENVPTR->ReleaseIntArrayElements(ENVPAR oType,otarr,JNI_ABORT);
+        ENVPTR->ReleaseLongArrayElements(ENVPAR oRef,refP,JNI_ABORT);
+        h5str_array_free(oName, n);
+        free(refs);
+        h5libraryError(env);
+        return -1;
+    }
+
+    ENVPTR->ReleaseIntArrayElements(ENVPAR lType,ltarr,0);
+    ENVPTR->ReleaseIntArrayElements(ENVPAR oType,otarr,0);
+
+    if (refs) {
+        for (i=0; i<n; i++) {
+            refP[i] = (jlong) refs[i];
+        }
+    }
+    free(refs);
+    ENVPTR->ReleaseLongArrayElements(ENVPAR oRef,refP,0);
+
+    if (oName) {
+        for (i=0; i<n; i++) {
+            if (*(oName+i)) {
+                str = ENVPTR->NewStringUTF(ENVPAR *(oName+i));
+                ENVPTR->SetObjectArrayElement(ENVPAR objName,i,(jobject)str);
+            }
+        } /* for (i=0; i<n; i++)*/
+    }
+
+    h5str_array_free(oName, n);
+
+    return ret_val;
+}
+
+int H5Gget_obj_info_all( hid_t loc_id, char **objname, int *otype, int *ltype, unsigned long *fno, unsigned long *objno, int indexType )
+{
     info_all_t info;
     info.objname = objname;
-    info.type = type;
+    info.otype = otype;
+    info.ltype = ltype;
+    info.idxnum = 0;
+    info.fno = fno;
     info.objno = objno;
     info.count = 0;
-   
-    retVal = H5Giterate(loc_id, group_name, NULL, obj_info_all, (void *)&info);
-    
-    return retVal;
+
+    if(H5Literate(loc_id, (H5_index_t)indexType, H5_ITER_INC, NULL, obj_info_all, (void *)&info) < 0){
+
+        /* iterate failed, try alphabetical order */
+        if(H5Literate(loc_id, H5_INDEX_NAME, H5_ITER_INC, NULL, obj_info_all, (void *)&info) < 0)
+            return -1;
+    }
+
+    return info.count;
 }
 
-herr_t obj_info_all(hid_t loc_id, const char *name, void *opdata)
+int H5Gget_obj_info_max( hid_t loc_id, char **objname, int *otype, int *ltype, unsigned long *objno, int maxnum )
+{
+    info_all_t info;
+    info.objname = objname;
+    info.otype = otype;
+    info.ltype = ltype;
+    info.idxnum = maxnum;
+    info.objno = objno;
+    info.count = 0;
+
+    if(H5Lvisit(loc_id, H5_INDEX_NAME, H5_ITER_NATIVE, obj_info_max, (void *)&info) < 0)
+        return -1;
+
+    return info.count;
+}
+
+herr_t obj_info_all(hid_t loc_id, const char *name, const H5L_info_t *info, void *op_data)
+{
+    int type = -1;
+    hid_t oid=-1;
+    herr_t retVal = -1;
+    info_all_t* datainfo = (info_all_t*)op_data;
+    H5O_info_t object_info;
+
+    retVal = H5Oget_info_by_name(loc_id, name, &object_info, H5P_DEFAULT);
+
+    if ( retVal < 0) {
+        *(datainfo->otype+datainfo->count) = -1;
+        *(datainfo->ltype+datainfo->count) = -1;
+        *(datainfo->objname+datainfo->count) = (char *) malloc(strlen(name)+1);
+        strcpy(*(datainfo->objname+datainfo->count), name);
+        *(datainfo->objno+datainfo->count) = -1;
+    }
+    else {
+        *(datainfo->otype+datainfo->count) = object_info.type;
+        *(datainfo->ltype+datainfo->count) = info->type;
+        *(datainfo->objname+datainfo->count) = (char *) malloc(strlen(name)+1);
+        strcpy(*(datainfo->objname+datainfo->count), name);
+
+		*(datainfo->fno+datainfo->count) = object_info.fileno;
+		*(datainfo->objno+datainfo->count) = object_info.addr;
+		/*
+        if(info->type==H5L_TYPE_HARD)
+            *(datainfo->objno+datainfo->count) = (unsigned long)info->u.address;
+        else
+            *(datainfo->objno+datainfo->count) = info->u.val_size;
+        */
+    }
+
+    datainfo->count++;
+
+    return 0;
+}
+
+herr_t obj_info_max(hid_t loc_id, const char *name, const H5L_info_t *info, void *op_data)
 {
     int type = -1;
     herr_t retVal = 0;
-    info_all_t* info = (info_all_t*)opdata;
-    H5G_stat_t statbuf;
+    info_all_t* datainfo = (info_all_t*)op_data;
+    H5O_info_t object_info;
 
-    retVal = H5Gget_objinfo(loc_id, name, 0, &statbuf);
-    
-    if (retVal < 0)
-    {
-        *(info->type+info->count) = -1;
-        *(info->objname+info->count) = NULL;
-        *(info->objno+info->count) = -1;
-    } else {
-        *(info->type+info->count) = statbuf.type;
-        *(info->objname+info->count) = (char *) malloc(strlen(name)+1);
-        strcpy(*(info->objname+info->count), name);
-        *(info->objno+info->count) = statbuf.objno[0];
+    retVal = H5Oget_info(loc_id, &object_info);
+    if ( retVal < 0) {
+        *(datainfo->otype+datainfo->count) = -1;
+        *(datainfo->ltype+datainfo->count) = -1;
+        *(datainfo->objname+datainfo->count) = NULL;
+        *(datainfo->objno+datainfo->count) = -1;
+        return 1;
     }
-    info->count++;
-
-    return retVal;
+    else {
+        *(datainfo->otype+datainfo->count) = object_info.type;
+        *(datainfo->ltype+datainfo->count) = info->type;
+        /* this will be freed by h5str_array_free(oName, n)*/
+        *(datainfo->objname+datainfo->count) = (char *) malloc(strlen(name)+1);
+        strcpy(*(datainfo->objname+datainfo->count), name);
+    if(info->type==H5L_TYPE_HARD)
+            *(datainfo->objno+datainfo->count) = (unsigned long)info->u.address;
+        else
+            *(datainfo->objno+datainfo->count) = info->u.val_size;
+    }
+    datainfo->count++;
+    if(datainfo->count < (int)datainfo->idxnum)
+        return 0;
+    else
+        return 1;
 }
 
+/*
+ * Create a java object of hdf.h5.structs.H5G_info_t
+ * public class H5G_info_t {
+ *   public H5G_STORAGE_TYPE  storage_type; // Type of storage for links in group
+ *   public long     nlinks;       // Number of links in group
+ *   public long     max_corder;   // Current max. creation order value for group
+ *   public int      mounted;      // Whether group has a file mounted on it
+ * }
+ *
+ */
+jobject create_H5G_info_t(JNIEnv *env, H5G_info_t group_info)
+{
+    jclass cls;
+    jboolean jmounted;
+    jint storage_type;
+    jobject obj;
+    jfieldID fid_storage_type, fid_nlinks, fid_max_corder, fid_mounted;
+
+    cls = ENVPTR->FindClass(ENVPAR "ncsa/hdf/hdf5lib/structs/H5G_info_t");
+    if (cls == NULL) return NULL;
+
+    obj = ENVPTR->AllocObject(ENVPAR cls);
+    if (obj == NULL) return NULL;
+
+    fid_storage_type = ENVPTR->GetFieldID(ENVPAR cls, "storage_type", "I");
+    fid_nlinks = ENVPTR->GetFieldID(ENVPAR cls, "nlinks", "J");
+    fid_max_corder = ENVPTR->GetFieldID(ENVPAR cls, "max_corder", "J");
+    fid_mounted = ENVPTR->GetFieldID(ENVPAR cls, "mounted", "Z");
+
+    if (fid_storage_type==NULL || fid_nlinks==NULL || fid_max_corder==NULL ||
+            fid_mounted == NULL)
+        return NULL;
+
+    jmounted = (group_info.mounted==0) ? JNI_FALSE : JNI_TRUE;
+    storage_type = (jint)group_info.storage_type;
+
+    ENVPTR->SetIntField(ENVPAR obj, fid_storage_type, (jint)storage_type);
+    ENVPTR->SetLongField(ENVPAR obj, fid_nlinks, (jlong)group_info.nlinks);
+    ENVPTR->SetLongField(ENVPAR obj, fid_max_corder, (jlong)group_info.max_corder);
+    ENVPTR->SetBooleanField(ENVPAR obj, fid_mounted, jmounted);
+
+    return obj;
+}
+
+/*
+ * Class:     ncsa_hdf_hdf5lib_H5
+ * Method:    _H5Gcreate2
+ * Signature: (ILjava/lang/String;III)I
+ */
+JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5__1H5Gcreate2
+  (JNIEnv *env, jclass clss, jint loc_id, jstring name,
+          jint link_plist_id, jint create_plist_id, jint access_plist_id)
+{
+    hid_t status;
+    char* gName;
+    jboolean isCopy;
+
+    if (name == NULL) {
+        h5nullArgument( env, "H5Gcreate:  name is NULL");
+        return -1;
+    }
+
+    gName = (char *)ENVPTR->GetStringUTFChars(ENVPAR name,&isCopy);
+
+    if (gName == NULL) {
+        h5JNIFatalError( env, "H5Gcreate:  file name not pinned");
+        return -1;
+    }
+
+    status = H5Gcreate2((hid_t)loc_id, gName, link_plist_id, create_plist_id, access_plist_id );
+
+    ENVPTR->ReleaseStringUTFChars(ENVPAR name,gName);
+    if (status < 0) {
+        h5libraryError(env);
+    }
+    return (jint)status;
+}
+
+/*
+ * Class:     ncsa_hdf_hdf5lib_H5
+ * Method:    _H5Gcreate_anon
+ * Signature: (III)I
+ */
+JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5__1H5Gcreate_1anon
+  (JNIEnv *env, jclass cls, jint loc_id, jint gcpl_id, jint gapl_id)
+{
+    hid_t ret_val;
+
+    ret_val = H5Gcreate_anon((hid_t)loc_id, (hid_t)gcpl_id, (hid_t)gapl_id);
+
+    if (ret_val < 0) {
+        h5libraryError(env);
+    }
+    return (jint)ret_val;
+}
+
+/*
+ * Class:     ncsa_hdf_hdf5lib_H5
+ * Method:    _H5Gopen2
+ * Signature: (ILjava/lang/String;I)I
+ */
+JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5__1H5Gopen2
+  (JNIEnv *env, jclass clss, jint loc_id, jstring name, jint access_plist_id)
+{
+    hid_t status;
+    char* gName;
+    jboolean isCopy;
+
+    if (name == NULL) {
+        h5nullArgument( env, "H5Gopen:  name is NULL");
+        return -1;
+    }
+
+    gName = (char *)ENVPTR->GetStringUTFChars(ENVPAR name,&isCopy);
+
+    if (gName == NULL) {
+        h5JNIFatalError( env, "H5Gopen:  file name not pinned");
+        return -1;
+    }
+
+    status = H5Gopen2((hid_t)loc_id, gName, (hid_t)access_plist_id );
+
+    ENVPTR->ReleaseStringUTFChars(ENVPAR name,gName);
+    if (status < 0) {
+        h5libraryError(env);
+    }
+    return (jint)status;
+}
+
+
+/*
+ * Class:     ncsa_hdf_hdf5lib_H5
+ * Method:    H5Gget_create_plist
+ * Signature: (I)I
+ */
+JNIEXPORT jint JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1create_1plist
+(JNIEnv *env, jclass cls, jint loc_id)
+{
+  hid_t ret_val;
+
+  ret_val = H5Gget_create_plist((hid_t)loc_id);
+
+  if (ret_val < 0) {
+      h5libraryError(env);
+  }
+
+  return (jint)ret_val;
+}
+
+/*
+ * Class:     ncsa_hdf_hdf5lib_H5
+ * Method:    H5Gget_info
+ * Signature: (I)Lncsa/hdf/hdf5lib/structs/H5G_info_t;
+ */
+JNIEXPORT jobject JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1info
+  (JNIEnv *env, jclass cls, jint loc_id)
+{
+    H5G_info_t group_info;
+    herr_t ret_val = -1;
+
+    ret_val = H5Gget_info( (hid_t) loc_id, &group_info);
+
+    if (ret_val < 0) {
+        h5libraryError(env);
+        return NULL;
+    }
+
+    return create_H5G_info_t(env, group_info);
+}
+
+/*
+ * Class:     ncsa_hdf_hdf5lib_H5
+ * Method:    H5Gget_info_by_name
+ * Signature: (ILjava/lang/String;I)Lncsa/hdf/hdf5lib/structs/H5G_info_t;
+ */
+JNIEXPORT jobject JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1info_1by_1name
+  (JNIEnv *env, jclass cls, jint loc_id, jstring name, jint lapl_id)
+{
+    H5G_info_t group_info;
+    herr_t ret_val = -1;
+    char* gName;
+    jboolean isCopy;
+
+    if (name == NULL) {
+        h5nullArgument( env, "H5Gget_info_by_name:  name is NULL");
+        return NULL;
+    }
+
+    gName = (char *)ENVPTR->GetStringUTFChars(ENVPAR name,&isCopy);
+
+    if (gName == NULL) {
+        h5JNIFatalError( env, "H5Gget_info_by_name:  file name not pinned");
+        return NULL;
+    }
+
+    ret_val = H5Gget_info_by_name((hid_t)loc_id, gName, &group_info, (hid_t)lapl_id);
+
+    ENVPTR->ReleaseStringUTFChars(ENVPAR name,gName);
+
+    if (ret_val < 0) {
+        h5libraryError(env);
+        return NULL;
+    }
+
+    return create_H5G_info_t(env, group_info);
+}
+
+/*
+ * Class:     ncsa_hdf_hdf5lib_H5
+ * Method:    H5Gget_info_by_idx
+ * Signature: (ILjava/lang/String;IIJI)Lncsa/hdf/hdf5lib/structs/H5G_info_t;
+ */
+JNIEXPORT jobject JNICALL Java_ncsa_hdf_hdf5lib_H5_H5Gget_1info_1by_1idx
+  (JNIEnv *env, jclass cls, jint loc_id, jstring name, jint index_type,
+          jint order, jlong n, jint lapl_id)
+{
+    H5G_info_t group_info;
+    herr_t ret_val = -1;
+    char* gName;
+    jboolean isCopy;
+    H5_index_t cindex_type = (H5_index_t)index_type;
+    H5_iter_order_t corder = (H5_iter_order_t)order;
+
+    if (name == NULL) {
+        h5nullArgument( env, "H5Gget_info_by_idx:  name is NULL");
+        return NULL;
+    }
+
+    gName = (char *)ENVPTR->GetStringUTFChars(ENVPAR name,&isCopy);
+
+    if (gName == NULL) {
+        h5JNIFatalError( env, "H5Gget_info_by_idx:  file name not pinned");
+        return NULL;
+    }
+
+    ret_val = H5Gget_info_by_idx((hid_t)loc_id, gName, cindex_type,
+            corder, (hsize_t)n, &group_info, (hid_t)lapl_id);
+
+    ENVPTR->ReleaseStringUTFChars(ENVPAR name,gName);
+
+    if (ret_val < 0) {
+        h5libraryError(env);
+        return NULL;
+    }
+
+    return create_H5G_info_t(env, group_info);
+}
 
 
 #ifdef __cplusplus
