@@ -31,10 +31,12 @@ extern "C" {
 
 #ifdef __cplusplus
 #define ENVPTR (env)
-#define ENVPAR 
+#define ENVPAR
+#define ENVONLY
 #else
 #define ENVPTR (*env)
 #define ENVPAR env,
+#define ENVONLY env
 #endif
 
 
@@ -890,11 +892,11 @@ JNIEXPORT jboolean JNICALL Java_ncsa_hdf_hdflib_HDFDeprecated_DFSDreadslab
 ( JNIEnv *env,
 jclass clss,
 jstring filename,
-jintArray start, 	/* IN: int[] */
-jintArray slab_size, 	/* IN: int[] */
-jintArray stride, 	/* IN: int[] */
-jbyteArray buffer,	/* OUT: byte[] */
-jintArray buffer_size)	/* OUT: int[] */
+jintArray start,   /* IN: int[] */
+jintArray slab_size,   /* IN: int[] */
+jintArray stride,   /* IN: int[] */
+jbyteArray buffer,  /* OUT: byte[] */
+jintArray buffer_size)  /* OUT: int[] */
 {
     intn rval;
     jbyte * dat;
