@@ -32,9 +32,11 @@ extern "C" {
 #ifdef __cplusplus
 #define ENVPTR (env)
 #define ENVPAR
+#define ENVONLY
 #else
 #define ENVPTR (*env)
 #define ENVPAR env,
+#define ENVONLY env
 #endif
 
 /* Name changed from MAX_GR_NAME to H4_MAX_GR_NAME in hdf4.2r2 */
