@@ -31,9 +31,11 @@ extern "C" {
 #ifdef __cplusplus
 #define ENVPTR (env)
 #define ENVPAR
+#define ENVONLY
 #else
 #define ENVPTR (*env)
 #define ENVPAR env,
+#define ENVONLY env
 #endif
 
 extern jboolean h4outOfMemory( JNIEnv *env, char *functName);
@@ -849,10 +851,10 @@ jint sdsid)
 
     rval = SDisrecord((int32)sdsid);
 
-    if (rval == FAIL) {
-        return JNI_FALSE;
-    } else {
+    if (rval == TRUE) {
         return JNI_TRUE;
+    } else {
+        return JNI_FALSE;
     }
 }
 
