@@ -14,13 +14,26 @@
 
 package ncsa.hdf.object.h4;
 
-import java.util.*;
 import java.io.File;
-
 import java.lang.reflect.Array;
-import javax.swing.tree.*;
-import ncsa.hdf.hdflib.*;
-import ncsa.hdf.object.*;
+import java.util.Enumeration;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Vector;
+
+import javax.swing.tree.DefaultMutableTreeNode;
+import javax.swing.tree.MutableTreeNode;
+import javax.swing.tree.TreeNode;
+
+import ncsa.hdf.hdflib.HDFConstants;
+import ncsa.hdf.hdflib.HDFException;
+import ncsa.hdf.hdflib.HDFLibrary;
+import ncsa.hdf.object.Attribute;
+import ncsa.hdf.object.Dataset;
+import ncsa.hdf.object.Datatype;
+import ncsa.hdf.object.FileFormat;
+import ncsa.hdf.object.Group;
+import ncsa.hdf.object.HObject;
 
 /**
  * This class provides file level APIs. File access APIs include retrieving the
@@ -31,7 +44,10 @@ import ncsa.hdf.object.*;
  */
 public class H4File extends FileFormat
 {
-    public static final long serialVersionUID = HObject.serialVersionUID;
+    /**
+     * 
+     */
+    private static final long serialVersionUID = 8985533001471224030L;
 
     // make sure that the library is loaded.
     static { HDFLibrary.loadH4Lib(); }
@@ -152,6 +168,7 @@ public class H4File extends FileFormat
      * @param fileformat the fileformat to be checked.
      * @return true if the given file is an HDF4 file; otherwise returns false.
      */
+    @Override
     public boolean isThisType(FileFormat fileformat)
     {
         return (fileformat instanceof H4File);
@@ -164,6 +181,7 @@ public class H4File extends FileFormat
      * @param filename the file to be checked.
      * @return true if the given file is an HDF4 file; otherwise returns false.
      */
+    @Override
     public boolean isThisType(String filename)
     {
         boolean isH4 = false;
@@ -192,6 +210,7 @@ public class H4File extends FileFormat
      * @see ncsa.hdf.object.FileFormat#createFile(java.lang.String, int)
      * @see #H4File(String, int)
      */
+    @Override
     public FileFormat createFile(String filename, int createFlag)
                                                         throws Exception
     {
@@ -209,9 +228,9 @@ public class H4File extends FileFormat
         if (doCreateFile) {
             int fileid = HDFLibrary.Hopen(filename, HDFConstants.DFACC_CREATE);
             try { 
-		HDFLibrary.Hclose(fileid); 
-	    } catch (HDFException ex) {}
-	}
+        HDFLibrary.Hclose(fileid); 
+        } catch (HDFException ex) {}
+    }
 
         return new H4File(filename, WRITE);
     }
@@ -222,13 +241,15 @@ public class H4File extends FileFormat
      * @see ncsa.hdf.object.FileFormat#createInstance(java.lang.String, int)
      * @see #H4File(String, int)
      */
+    @Override
     public FileFormat createInstance(String filename, int access) 
-							throws Exception
+                            throws Exception
     {
         return new H4File(filename, access);
     }
 
     // Implementing FileFormat
+    @Override
     public int open() throws Exception
     {
         if ( fid >=0 ) {
@@ -278,6 +299,7 @@ public class H4File extends FileFormat
     }
 
     // Implementing FileFormat
+    @Override
     public void close() throws HDFException
     {
         // clean unused objects
@@ -309,17 +331,20 @@ public class H4File extends FileFormat
     }
 
     // Implementing FileFormat
+    @Override
     public TreeNode getRootNode()
     {
         return rootNode;
     }
 
 
+    @Override
     public Group createGroup(String name, Group pgroup) throws Exception
     {
         return H4Group.create(name, pgroup);
     }
 
+    @Override
     public Datatype createDatatype(
         int tclass,
         int tsize,
@@ -329,6 +354,7 @@ public class H4File extends FileFormat
         return new H4Datatype(tclass, tsize, torder, tsign);
     }
 
+    @Override
     public Datatype createDatatype(
         int tclass,
         int tsize,
@@ -339,6 +365,7 @@ public class H4File extends FileFormat
         throw new UnsupportedOperationException("HDF4 does not support named datatype.");
     }
 
+    @Override
     public Dataset createScalarDS(
         String name,
         Group pgroup,
@@ -347,12 +374,14 @@ public class H4File extends FileFormat
         long[] maxdims,
         long[] chunks,
         int gzip,
+        Object fillValue,
         Object data) throws Exception
     {
-        return H4SDS.create(name, pgroup, type, dims, maxdims, chunks, gzip, data);
+        return H4SDS.create(name, pgroup, type, dims, maxdims, chunks, gzip, fillValue, data);
     }
 
 
+    @Override
     public Dataset createImage(
         String name,
         Group pgroup,
@@ -374,6 +403,7 @@ public class H4File extends FileFormat
      * Delete an object from the file.
      * @param obj the data object to delete.
      */
+    @Override
     public void delete(HObject obj) throws Exception
     {
         throw (new UnsupportedOperationException(
@@ -386,6 +416,7 @@ public class H4File extends FileFormat
      * @param dstGroup the destination group.
      * @return the new node containing the new object.
      */
+    @Override
     public TreeNode copy(HObject srcObj, Group dstGroup, String dstName) throws Exception
     {
         TreeNode newNode = null;
@@ -419,22 +450,17 @@ public class H4File extends FileFormat
 
         return newNode;
     }
-
-    // implementign FileFormat
-    public HObject createLink(Group parentGroup, String name, HObject currentObj) throws Exception
-    {
-        throw new UnsupportedOperationException("createLink() is not supported");
-    }
-
+    
     /**
      * Creates a new attribute and attached to the object if attribute does
      * not exist. Otherwise, just update the value of the attribute.
      *
      * <p>
      * @param obj the object which the attribute is to be attached to.
-     * @param attr the atribute to attach.
+     * @param attr the attribute to attach.
      * @param isSDglobalAttr The indicator if the given attribute exists.
      */
+    @Override
     public void writeAttribute(HObject obj, Attribute attr,
         boolean isSDglobalAttr) throws HDFException
     {
@@ -554,8 +580,9 @@ public class H4File extends FileFormat
 
         DefaultMutableTreeNode newNode = new DefaultMutableTreeNode(group)
         {
-        	public static final long serialVersionUID = HObject.serialVersionUID;
+            private static final long serialVersionUID = -8601910527549035409L;
 
+            @Override
             public boolean isLeaf() { return false; }
         };
         pgroup.addToMemberList(group);
@@ -602,15 +629,16 @@ public class H4File extends FileFormat
 
         H4Group rootGroup = new H4Group(
             this,
-            getName(), // set the node name to the file name
+            "/", 
             null, // root node does not have a parent path
             null, // root node does not have a parent node
             oid);
 
         DefaultMutableTreeNode root = new DefaultMutableTreeNode(rootGroup)
         {
-        	public static final long serialVersionUID = HObject.serialVersionUID;
+            private static final long serialVersionUID = 3507473044690724650L;
 
+            @Override
             public boolean isLeaf() { return false; }
         };
 
@@ -645,8 +673,9 @@ public class H4File extends FileFormat
             {
                 node = new DefaultMutableTreeNode(g)
                 {
-                	public static final long serialVersionUID = HObject.serialVersionUID;
+                    private static final long serialVersionUID = 8927502967802143369L;
 
+                    @Override
                     public boolean isLeaf() { return false; }
                 };
                 root.add( node );
@@ -875,8 +904,9 @@ public class H4File extends FileFormat
                     {
                         node = new DefaultMutableTreeNode(vgroup)
                         {
-                        	public static final long serialVersionUID = HObject.serialVersionUID;
+                            private static final long serialVersionUID = -8774836537322039221L;
 
+                            @Override
                             public boolean isLeaf() { return false; }
                         };
 
@@ -1445,6 +1475,7 @@ public class H4File extends FileFormat
     /**
      *  Returns the version of the HDF4 library.
      */
+    @Override
     public String getLibversion()
     {
         int[] vers = new int[3];
@@ -1503,6 +1534,7 @@ public class H4File extends FileFormat
      * Get an individual HObject with a given path. It deoes not load the whole
      * file structure.
      */
+    @Override
     public HObject get(String path) throws Exception
     {
         if (objList == null) {
