@@ -14,10 +14,14 @@
 
 package ncsa.hdf.view;
 
-import ncsa.hdf.object.*;
-
-import javax.swing.*;
-
+import java.awt.BorderLayout;
+import java.awt.Component;
+import java.awt.Dimension;
+import java.awt.Event;
+import java.awt.Font;
+import java.awt.GridLayout;
+import java.awt.Insets;
+import java.awt.Toolkit;
 import java.awt.datatransfer.DataFlavor;
 import java.awt.datatransfer.Transferable;
 import java.awt.datatransfer.UnsupportedFlavorException;
@@ -27,24 +31,56 @@ import java.awt.dnd.DropTargetDragEvent;
 import java.awt.dnd.DropTargetDropEvent;
 import java.awt.dnd.DropTargetEvent;
 import java.awt.dnd.DropTargetListener;
-import java.awt.event.*;
-import java.io.*;
-import java.text.DecimalFormat;
-import java.text.NumberFormat;
-import java.util.*;
-
-import javax.swing.event.*;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
+import java.awt.event.KeyEvent;
+import java.io.BufferedInputStream;
+import java.io.BufferedOutputStream;
+import java.io.File;
+import java.io.FileOutputStream;
+import java.io.IOException;
+import java.lang.reflect.Constructor;
 import java.net.URL;
-import java.lang.reflect.*;
-import java.awt.Event;
-import java.awt.Insets;
-import java.awt.Dimension;
-import java.awt.Component;
-import java.awt.BorderLayout;
-import java.awt.GridLayout;
-import java.awt.Toolkit;
-import java.awt.Image;
-import java.awt.Font;
+import java.util.ArrayList;
+import java.util.Enumeration;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Vector;
+
+import javax.swing.ImageIcon;
+import javax.swing.JButton;
+import javax.swing.JComboBox;
+import javax.swing.JComponent;
+import javax.swing.JDesktopPane;
+import javax.swing.JDialog;
+import javax.swing.JFileChooser;
+import javax.swing.JFrame;
+import javax.swing.JInternalFrame;
+import javax.swing.JMenu;
+import javax.swing.JMenuBar;
+import javax.swing.JMenuItem;
+import javax.swing.JOptionPane;
+import javax.swing.JPanel;
+import javax.swing.JScrollPane;
+import javax.swing.JSplitPane;
+import javax.swing.JTabbedPane;
+import javax.swing.JTextArea;
+import javax.swing.JToolBar;
+import javax.swing.KeyStroke;
+import javax.swing.SwingUtilities;
+import javax.swing.UIDefaults;
+import javax.swing.UIManager;
+import javax.swing.event.ChangeEvent;
+import javax.swing.event.ChangeListener;
+
+import ncsa.hdf.object.Attribute;
+import ncsa.hdf.object.CompoundDS;
+import ncsa.hdf.object.Dataset;
+import ncsa.hdf.object.Datatype;
+import ncsa.hdf.object.FileFormat;
+import ncsa.hdf.object.Group;
+import ncsa.hdf.object.HObject;
+import ncsa.hdf.object.ScalarDS;
 
 /**
  * HDFView is the main class of this HDF visual tool.
@@ -65,12 +101,13 @@ import java.awt.Font;
 public class HDFView extends JFrame implements ViewManager, ActionListener, 
 ChangeListener, DropTargetListener
 {
-  public static final long serialVersionUID = HObject.serialVersionUID;
+    private static final long serialVersionUID = 2211017444445918998L;
+
     /** a list of tree view implementation. */
-    private static List treeViews;
+    private static List<String> treeViews;
 
     /** a list of image view implementation. */
-    private static List imageViews;
+    private static List<String> imageViews;
 
     /** a list of tree table implementation. */
     private static List tableViews;
@@ -90,10 +127,10 @@ ChangeListener, DropTargetListener
     private static final String aboutHDFView =
         "HDF Viewer, "+ "Version "+ViewProperties.VERSION+"\n"+
         "For "+System.getProperty("os.name")+"\n\n"+
-        "Copyright "+'\u00a9'+" 2006-2010 The HDF Group.\n"+
+        "Copyright "+'\u00a9'+" 2006-2011 The HDF Group.\n"+
         "All rights reserved.";
 
-    private static final String JAVA_COMPILER = "jdk 1.6.0";
+    private static final String JAVA_COMPILER = "jdk 1.6";
 
     /** the directory where the HDFView is installed */
     private String rootDir;
@@ -149,10 +186,10 @@ ChangeListener, DropTargetListener
     private final List editGUIs;
 
     /** The list of GUI components related to HDF5 */
-    private final List h5GUIs;
+    private final List<JMenuItem> h5GUIs;
 
     /** The list of GUI components related to HDF4 */
-    private final List h4GUIs;
+    private final List<JMenuItem> h4GUIs;
 
     /** to add and display url */
     private JComboBox urlBar;
@@ -170,9 +207,10 @@ ChangeListener, DropTargetListener
      * @param root the directory where the HDFView is installed.
      * @param flist a list of files to open.
      */
-    public HDFView(String root, List flist, int width, int height, int x, int y)
+    public HDFView(String root, List<File> flist, int width, int height, int x, int y)
     {
         super("HDFView");
+        this.setName("hdfview");
 
         setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
         
@@ -188,8 +226,8 @@ ChangeListener, DropTargetListener
         ViewProperties.loadExtClass();
 
         editGUIs = new Vector();
-        h4GUIs = new Vector();
-        h5GUIs = new Vector();
+        h4GUIs = new Vector<JMenuItem>();
+        h5GUIs = new Vector<JMenuItem>();
 
         // load the view properties
         props = new ViewProperties(rootDir);
@@ -214,6 +252,7 @@ ChangeListener, DropTargetListener
         statusArea.setEditable(false);
         statusArea.setBackground(new java.awt.Color(240, 240, 240));
         statusArea.setLineWrap(true);
+        statusArea.setName("status");
         message = new StringBuffer();
         metadata = new StringBuffer();
         showStatus("HDFView root - "+rootDir);
@@ -223,20 +262,25 @@ ChangeListener, DropTargetListener
         attributeArea.setEditable(false);
         attributeArea.setBackground(new java.awt.Color(240, 240, 240));
         attributeArea.setLineWrap(true);
+        attributeArea.setName("attributes");
 
         // create tab pane to display attributes and status information
         infoTabbedPane = new JTabbedPane(JTabbedPane.BOTTOM);
         infoTabbedPane.addChangeListener(this);
+        infoTabbedPane.setName("tabpane");
 
         contentPane = new JDesktopPane();
+        contentPane.setName("contentpane");
         windowMenu = new JMenu( "Window" );
+        windowMenu.setName("windowmenu");
         fileMenu = new JMenu( "File" );
+        fileMenu.setName("filemenu");
 
         int n = treeViews.size();
         Class theClass = null;
         for (int i=0; i<n; i++)  {
           // use the first available treeview
-            String className = (String)treeViews.get(i);
+            String className = treeViews.get(i);
             // enables use of JHDF5 in JNLP (Web Start) applications, the system class loader with reflection first.
             try { theClass = Class.forName(className); }
             catch (Exception ex)
@@ -287,7 +331,7 @@ ChangeListener, DropTargetListener
 
         File theFile = null;
         for (int i=0; i<nfiles; i++) {
-            theFile = (File)flist.get(i);
+            theFile = flist.get(i);
             if (theFile.isFile()) {
                 currentDir = theFile.getParentFile().getAbsolutePath();
                 currentFile = theFile.getAbsolutePath();
@@ -355,12 +399,15 @@ ChangeListener, DropTargetListener
     {
         // create splitpane to separate treeview and the contentpane
         JScrollPane treeScroller = new JScrollPane((Component)treeView);
+        treeScroller.setName("treescroller");
         JScrollPane contentScroller = new JScrollPane(contentPane);
+        contentScroller.setName("contentscroller");
         JSplitPane topSplitPane = new JSplitPane(
             JSplitPane.HORIZONTAL_SPLIT,
             treeScroller,
             contentScroller);
         topSplitPane.setDividerLocation(200);
+        topSplitPane.setName("topsplitpane");
 
         infoTabbedPane.addTab("Log Info", new JScrollPane(statusArea));
         infoTabbedPane.addTab("Metadata ", new JScrollPane(attributeArea));
@@ -372,6 +419,7 @@ ChangeListener, DropTargetListener
             JSplitPane.VERTICAL_SPLIT,
             topSplitPane,
             infoTabbedPane);
+        splitPane.setName("splitpane");
 
         // set the window size
         //float inset = 0.17f; // for UG only.
@@ -417,26 +465,41 @@ ChangeListener, DropTargetListener
 
         JPanel urlPane = new JPanel();
         urlPane.setLayout(new BorderLayout());
-        JButton b = new JButton("File/URL");
-        urlPane.add(b, BorderLayout.WEST);
+        urlPane.setName("urlpane");
+        
+        JButton b = new JButton("Clear Text");
+        b.setActionCommand("Clear current selection");
+        b.setToolTipText("Clear current selection");
+        b.setMargin(new Insets(1,3,1,3));
+        b.addActionListener(this);
+        urlPane.add(b, BorderLayout.EAST);
+
+        b = new JButton("Recent Files");
         b.addActionListener(this);
         b.setActionCommand("Popup URL list");
+        b.setToolTipText("List of recent files");
+        b.setMargin(new Insets(1,3,1,3));
+        urlPane.add(b, BorderLayout.WEST);
+       
         urlPane.add(urlBar, BorderLayout.CENTER);
         JPanel toolPane = new JPanel();
         toolPane.setLayout(new GridLayout(2,1,0,0));
         toolPane.add(toolBar);
         toolPane.add(urlPane);
+        toolPane.setName("toolpane");
 
         JPanel mainPane = (JPanel)getContentPane();
         mainPane.setLayout(new BorderLayout());
         mainPane.add(toolPane, BorderLayout.NORTH);
         mainPane.add(splitPane, BorderLayout.CENTER);
         mainPane.setPreferredSize(d);
+        mainPane.setName("mainpane");
     }
 
     private JMenuBar createMenuBar()
     {
         JMenuBar mbar = new JMenuBar();
+        mbar.setName("mbar");
         JMenu menu = null;
         JMenuItem item;
 
@@ -671,10 +734,12 @@ ChangeListener, DropTargetListener
     {
         JToolBar tbar = new JToolBar();
         tbar.setFloatable(false);
+        tbar.setName("tbar");
 
         // open file button
         JButton button = new JButton(ViewProperties.getFileopenIcon() );
         tbar.add( button );
+        button.setName("Open");
         button.setToolTipText( "Open" );
         button.addActionListener( this );
         button.setActionCommand( "Open file" );
@@ -682,6 +747,7 @@ ChangeListener, DropTargetListener
         // close file button
         button = new JButton(ViewProperties.getFilecloseIcon() );
         tbar.add( button );
+        button.setName("Close");
         button.setToolTipText( "Close" );
         button.addActionListener( this );
         button.setActionCommand( "Close file" );
@@ -691,6 +757,7 @@ ChangeListener, DropTargetListener
         // help button
         button = new JButton( ViewProperties.getHelpIcon() );
         tbar.add( button );
+        button.setName("Help");
         button.setToolTipText( "Help" );
         button.addActionListener( this );
         button.setActionCommand( "Users guide" );
@@ -698,6 +765,7 @@ ChangeListener, DropTargetListener
         // HDF4 Library Version button
         button = new JButton( ViewProperties.getH4Icon() );
         tbar.add( button );
+        button.setName("HDF4 library");
         button.setToolTipText( "HDF4 Library Version" );
         button.addActionListener( this );
         button.setActionCommand( "HDF4 library" );
@@ -708,6 +776,7 @@ ChangeListener, DropTargetListener
         // HDF5 Library Version button
         button = new JButton( ViewProperties.getH5Icon() );
         tbar.add( button );
+        button.setName("HDF5 library");
         button.setToolTipText( "HDF5 Library Version" );
         button.addActionListener( this );
         button.setActionCommand( "HDF5 library" );
@@ -828,13 +897,13 @@ ChangeListener, DropTargetListener
     }
 
     /** disable/enable GUI components */
-    private static void setEnabled(List list, boolean b)
+    private static void setEnabled(List<JMenuItem> list, boolean b)
     {
         Component item = null;
-        Iterator it = list.iterator();
+        Iterator<JMenuItem> it = list.iterator();
         while (it.hasNext())
         {
-            item = (Component)it.next();
+            item = it.next();
             item.setEnabled(b);
         }
     }
@@ -851,7 +920,7 @@ ChangeListener, DropTargetListener
         {
             int fileAccessID = FileFormat.WRITE;
             String filename = null;
-            
+
             if (ViewProperties.isReadOnly())
                 fileAccessID = FileFormat.READ;
 
@@ -866,10 +935,10 @@ ChangeListener, DropTargetListener
                 if (!(filename.startsWith("http://") || filename.startsWith("ftp://")))
                 {
                     File tmpFile = new File(filename);
-                    
+
                     if (!tmpFile.exists())
-                      return;
-                    
+                        return;
+
                     if (tmpFile.isDirectory())
                     {
                         currentDir = filename;
@@ -899,8 +968,8 @@ ChangeListener, DropTargetListener
             }
 
             if ((filename == null) ||
-                (filename.length() < 1) ||
-                filename.equals(currentFile)) {
+                    (filename.length() < 1) ||
+                    filename.equals(currentFile)) {
                 return;
             }
 
@@ -932,10 +1001,10 @@ ChangeListener, DropTargetListener
             {
                 toolkit.beep();
                 JOptionPane.showMessageDialog(
-                    this,
-                    ex,
-                    getTitle(),
-                    JOptionPane.ERROR_MESSAGE);
+                        this,
+                        ex,
+                        getTitle(),
+                        JOptionPane.ERROR_MESSAGE);
             }
         }
         else if (cmd.startsWith("New HDF"))
@@ -946,6 +1015,7 @@ ChangeListener, DropTargetListener
             }
 
             NewFileDialog dialog = new NewFileDialog(this, currentDir, ftype, treeView.getCurrentFiles());
+            dialog.setName("newfiledialog");
             //dialog.show();
 
             if (!dialog.isFileCreated()) {
@@ -968,10 +1038,10 @@ ChangeListener, DropTargetListener
             {
                 toolkit.beep();
                 JOptionPane.showMessageDialog(
-                    this,
-                    ex.getMessage()+"\n"+filename,
-                    getTitle(),
-                    JOptionPane.ERROR_MESSAGE);
+                        this,
+                        ex.getMessage()+"\n"+filename,
+                        getTitle(),
+                        JOptionPane.ERROR_MESSAGE);
             }
         }
         else if (cmd.equals("Close file"))
@@ -1019,14 +1089,14 @@ ChangeListener, DropTargetListener
         else if (cmd.equals("Close all file"))
         {
             closeAllWindow();
-            List files = treeView.getCurrentFiles();
+            List<FileFormat> files = treeView.getCurrentFiles();
 
             while(!files.isEmpty()) {
-                try { treeView.closeFile((FileFormat)files.get(0)); }
+                try { treeView.closeFile(files.get(0)); }
                 catch (Exception ex) {}
             }
             currentFile = null;
-            
+
             attributeArea.setText("");
         }
         else if (cmd.equals("Save current file as"))
@@ -1037,7 +1107,7 @@ ChangeListener, DropTargetListener
             catch (Exception ex) {
                 toolkit.beep();
                 JOptionPane.showMessageDialog(
-                    this, ex, getTitle(), JOptionPane.ERROR_MESSAGE);
+                        this, ex, getTitle(), JOptionPane.ERROR_MESSAGE);
             }
         }
         else if (cmd.equals("Save current file"))
@@ -1045,7 +1115,7 @@ ChangeListener, DropTargetListener
             /* save what have been changed in memory into file */
             try {
                 FileFormat file = treeView.getSelectedFile();
-                List views = getDataViews();
+                List<JInternalFrame> views = getDataViews();
                 Object theView = null;
                 TableView tableView = null;
                 TextView textView = null;
@@ -1080,7 +1150,7 @@ ChangeListener, DropTargetListener
             catch (Exception ex) {
                 toolkit.beep();
                 JOptionPane.showMessageDialog(
-                    this, ex, getTitle(), JOptionPane.ERROR_MESSAGE);
+                        this, ex, getTitle(), JOptionPane.ERROR_MESSAGE);
             }
         }
         else if (cmd.equals("Cascade all windows"))
@@ -1115,23 +1185,23 @@ ChangeListener, DropTargetListener
 
             if (cmd.equals("Convert image file: Image to HDF5"))
             {
-              typeFrom = Tools.FILE_TYPE_IMAGE;
+                typeFrom = Tools.FILE_TYPE_IMAGE;
                 typeTo = FileFormat.FILE_TYPE_HDF5;
             }
             else if (cmd.equals("Convert image file: Image to HDF4"))
             {
-              typeFrom = Tools.FILE_TYPE_IMAGE;
+                typeFrom = Tools.FILE_TYPE_IMAGE;
                 typeTo = FileFormat.FILE_TYPE_HDF4;
             } else {
                 return;
             }
 
             FileConversionDialog dialog = new FileConversionDialog(
-                this,
-                typeFrom,
-                typeTo,
-                currentDir,
-                treeView.getCurrentFiles());
+                    this,
+                    typeFrom,
+                    typeTo,
+                    currentDir,
+                    treeView.getCurrentFiles());
             dialog.setVisible(true);
 
             if (dialog.isFileConverted())
@@ -1161,39 +1231,39 @@ ChangeListener, DropTargetListener
         }
         else if (cmd.equals("User options"))
         {
-          if (userOptionDialog == null) {
+            if (userOptionDialog == null) {
                 userOptionDialog = new UserOptionsDialog(this, rootDir);
             }
 
-          userOptionDialog.setVisible(true);
+            userOptionDialog.setVisible(true);
 
             if (userOptionDialog.isWorkDirChanged())
             {
                 currentDir = ViewProperties.getWorkDir();
             }
-            
+
             if (userOptionDialog.isFontChanged()) {
-              Font font = null;
-              try { 
-                font = new Font(ViewProperties.getFontType(), Font.PLAIN, ViewProperties.getFontSize());
-              } catch (Exception ex) { font = null; }
-              
-              if (font != null) {
+                Font font = null;
+                try { 
+                    font = new Font(ViewProperties.getFontType(), Font.PLAIN, ViewProperties.getFontSize());
+                } catch (Exception ex) { font = null; }
+
+                if (font != null) {
                     updateFontSize(font);
-              }
+                }
             }
         }
         else if (cmd.equals("Register file format")) {
             String msg = "Register a new file format by \nKEY:FILE_FORMAT:FILE_EXTENSION\n"+
-                "where, KEY: the unique identifier for the file format"+
-                "\n           FILE_FORMAT: the full class name of the file format"+
-                "\n           FILE_EXTENSION: the file extension for the file format"+
-                "\n\nFor example, "+
-                "\n\t to add NetCDF, \"NetCDF:ncsa.hdf.object.nc2.NC2File:nc\"" +
-                "\n\t to add FITS, \"FITS:ncsa.hdf.object.fits.FitsFile:fits\"\n\n";
-             String str = (String)JOptionPane.showInputDialog(this, msg, "Register a file format", 
-                   JOptionPane.PLAIN_MESSAGE, ViewProperties.getLargeHdfIcon(), 
-                   null, null);
+            "where, KEY: the unique identifier for the file format"+
+            "\n           FILE_FORMAT: the full class name of the file format"+
+            "\n           FILE_EXTENSION: the file extension for the file format"+
+            "\n\nFor example, "+
+            "\n\t to add NetCDF, \"NetCDF:ncsa.hdf.object.nc2.NC2File:nc\"" +
+            "\n\t to add FITS, \"FITS:ncsa.hdf.object.fits.FitsFile:fits\"\n\n";
+            String str = (String)JOptionPane.showInputDialog(this, msg, "Register a file format", 
+                    JOptionPane.PLAIN_MESSAGE, ViewProperties.getLargeHdfIcon(), 
+                    null, null);
             if ((str == null) || (str.length()<1)) {
                 return;
             }
@@ -1216,25 +1286,25 @@ ChangeListener, DropTargetListener
             // check is the file format has been registered or the key is taken.
             String theKey = null;
             String theClassName = null;
-            Enumeration local_enum = FileFormat.getFileFormatKeys();
+            Enumeration<?> local_enum = FileFormat.getFileFormatKeys();
             while (local_enum.hasMoreElements()) {
                 theKey = (String)local_enum.nextElement();
                 if (theKey.endsWith(key)) {
                     JOptionPane.showMessageDialog(
-                        this,
-                        "Invalid key: "+key+" is taken.",
-                        "Register File Format",
-                        JOptionPane.ERROR_MESSAGE);
+                            this,
+                            "Invalid key: "+key+" is taken.",
+                            "Register File Format",
+                            JOptionPane.ERROR_MESSAGE);
                     return;
                 }
 
                 theClassName = FileFormat.getFileFormat(theKey).getClass().getName();
                 if (theClassName.endsWith(className)) {
                     JOptionPane.showMessageDialog(
-                        this,
-                        "The file format has already been registered: "+className,
-                        "Register File Format",
-                        JOptionPane.ERROR_MESSAGE);
+                            this,
+                            "The file format has already been registered: "+className,
+                            "Register File Format",
+                            JOptionPane.ERROR_MESSAGE);
                     return;
                 }
             }
@@ -1266,10 +1336,10 @@ ChangeListener, DropTargetListener
 
             if ((extension != null) && (extension.length()>0))
             {
-               extension = extension.trim();
-               String ext = ViewProperties.getFileExtension();
-               ext += ", "+extension;
-               ViewProperties.setFileExtension(ext);
+                extension = extension.trim();
+                String ext = ViewProperties.getFileExtension();
+                ext += ", "+extension;
+                ViewProperties.setFileExtension(ext);
             }
         }
         else if (cmd.equals("Unregister file format")) {
@@ -1281,9 +1351,9 @@ ChangeListener, DropTargetListener
             }
 
             String theKey = (String)JOptionPane.showInputDialog(this,
-                "Unregister a file format", "Unregister a file format",
-                JOptionPane.WARNING_MESSAGE, ViewProperties.getLargeHdfIcon(), keylist.toArray(),
-                null);
+                    "Unregister a file format", "Unregister a file format",
+                    JOptionPane.WARNING_MESSAGE, ViewProperties.getLargeHdfIcon(), keylist.toArray(),
+                    null);
 
             if (theKey == null) {
                 return;
@@ -1330,11 +1400,11 @@ ChangeListener, DropTargetListener
             }
 
             JOptionPane.showMessageDialog(
-                this,
-                thefile.getLibversion(),
-                "HDFView",
-                JOptionPane.PLAIN_MESSAGE,
-                ViewProperties.getLargeHdfIcon());
+                    this,
+                    thefile.getLibversion(),
+                    "HDFView",
+                    JOptionPane.PLAIN_MESSAGE,
+                    ViewProperties.getLargeHdfIcon());
         }
         else if (cmd.equals("HDF5 library"))
         {
@@ -1344,26 +1414,26 @@ ChangeListener, DropTargetListener
             }
 
             JOptionPane.showMessageDialog(
-                this,
-                thefile.getLibversion(),
-                "HDFView",
-                JOptionPane.PLAIN_MESSAGE,
-                ViewProperties.getLargeHdfIcon());
+                    this,
+                    thefile.getLibversion(),
+                    "HDFView",
+                    JOptionPane.PLAIN_MESSAGE,
+                    ViewProperties.getLargeHdfIcon());
         }
         else if (cmd.equals("Java version"))
         {
             String info = "Compiled at "+JAVA_COMPILER+
-                "\nRunning at "+System.getProperty("java.vm.version");
+            "\nRunning at "+System.getProperty("java.vm.version");
             JOptionPane.showMessageDialog(
-                this,
-                info,
-                "HDFView",
-                JOptionPane.PLAIN_MESSAGE,
-                ViewProperties.getLargeHdfIcon());
+                    this,
+                    info,
+                    "HDFView",
+                    JOptionPane.PLAIN_MESSAGE,
+                    ViewProperties.getLargeHdfIcon());
         }
         else if (cmd.equals("File format list"))
         {
-            Enumeration formatKeys = FileFormat.getFileFormatKeys();
+            Enumeration<?> formatKeys = FileFormat.getFileFormatKeys();
 
             String str = "\nSupported File Formats: \n";
             while (formatKeys.hasMoreElements()) {
@@ -1372,24 +1442,29 @@ ChangeListener, DropTargetListener
             str += "\n";
 
             JOptionPane.showMessageDialog(
-                this,
-                str,
-                "HDFView",
-                JOptionPane.PLAIN_MESSAGE,
-                ViewProperties.getLargeHdfIcon());
+                    this,
+                    str,
+                    "HDFView",
+                    JOptionPane.PLAIN_MESSAGE,
+                    ViewProperties.getLargeHdfIcon());
         }
         else if (cmd.equals("About"))
         {
             JOptionPane.showMessageDialog(
-                this,
-                aboutHDFView,
-                "HDFView",
-                JOptionPane.PLAIN_MESSAGE,
-                ViewProperties.getLargeHdfIcon());
+                    this,
+                    aboutHDFView,
+                    "HDFView",
+                    JOptionPane.PLAIN_MESSAGE,
+                    ViewProperties.getLargeHdfIcon());
         }
         else if (cmd.equals("Popup URL list"))
         {
             urlBar.setPopupVisible(true);
+        }
+        else if (cmd.equals("Clear current selection"))
+        {
+            //urlBar.setPopupVisible(true);
+            urlBar.setSelectedIndex(-1);
         } else
         {
             if ((helpViews == null) || (helpViews.size() <= 0)) {
@@ -1506,7 +1581,7 @@ ChangeListener, DropTargetListener
 
         // close all open files
         try {
-        List filelist = treeView.getCurrentFiles();
+        List<FileFormat> filelist = treeView.getCurrentFiles();
         if ((filelist != null) && (filelist.size()>0)) {
             Object[] files = filelist.toArray();
             int n = files.length;
@@ -1729,6 +1804,23 @@ ChangeListener, DropTargetListener
         } // else if (obj instanceof Dataset)
 
         List attrList = null;
+        //-----------For the feature:To display attributes in creation order
+        //        String idxType = ViewProperties.getIndexType();
+        //        int indxType = 0;
+        //        if(idxType.equals("alphabetical"))
+        //            indxType = 0;
+        //        else if(idxType.equals("creation"))
+        //            indxType = 1;
+        //        try { 
+        //            if(obj.getFileFormat().isThisType(FileFormat.getFileFormat(FileFormat.FILE_TYPE_HDF5))){
+        //                attrList = obj.getMetadata(indxType);
+        //            } 
+        //            else
+        //                attrList = obj.getMetadata();
+        //        }
+        //        catch (Exception ex){
+        //            ex.printStackTrace();
+        //        }
         try { attrList = obj.getMetadata(); } catch (Exception ex) {ex.printStackTrace();}
 
         if (attrList == null) {
@@ -1794,7 +1886,7 @@ ChangeListener, DropTargetListener
 
     /** Returns a list of all open DataViews
      */
-    public List getDataViews()
+    public List<JInternalFrame> getDataViews()
     {
         // check if the data content is already displayed
         JInternalFrame[] frames = contentPane.getAllFrames();
@@ -1804,7 +1896,7 @@ ChangeListener, DropTargetListener
             return null;
         }
 
-        Vector views = new Vector(frames.length);
+        Vector<JInternalFrame> views = new Vector<JInternalFrame>(frames.length);
         HObject obj = null;
         for (int i=0; i<frames.length; i++)
         {
@@ -1821,14 +1913,14 @@ ChangeListener, DropTargetListener
     /**
      * @return a list of treeview implementations.
      */
-    public static final List getListOfTreeView() {
+    public static final List<String> getListOfTreeView() {
         return treeViews;
     }
 
     /**
      * @return a list of imageview implementations.
      */
-    public static final List getListOfImageView() {
+    public static final List<String> getListOfImageView() {
         return imageViews;
     }
 
@@ -2026,8 +2118,8 @@ ChangeListener, DropTargetListener
     private static final void loadExtModules() throws Exception
     {
         ClassLoader extClassLoader = ViewProperties.loadExtClass();
-        Vector moduleListTreeView  = ViewProperties.getTreeViewList();
-        Vector moduleListImageView = ViewProperties.getImageViewList();
+        Vector<String> moduleListTreeView  = ViewProperties.getTreeViewList();
+        Vector<String> moduleListImageView = ViewProperties.getImageViewList();
         
         if (extClassLoader == null ||
                 moduleListTreeView == null ||
@@ -2148,7 +2240,7 @@ ChangeListener, DropTargetListener
             }
         }
 
-        Vector flist = new Vector();
+        Vector<File> flist = new Vector<File>();
         tmpFile = null;
         if (j>=0) {
             for (i = j; i<args.length; i++) {
@@ -2158,9 +2250,20 @@ ChangeListener, DropTargetListener
                 }
             }
         }
+        
+        final Vector<File> the_flist = flist;
+        final String the_rootDir = rootDir;
+        final int the_X=X, the_Y=Y, the_W=W, the_H=H;
+        
+        //Schedule a job for the event-dispatching thread:
+        //creating and showing this application's GUI.
+        javax.swing.SwingUtilities.invokeLater(new Runnable() {
+            public void run() {
+                HDFView frame = new HDFView(the_rootDir, the_flist, the_W, the_H, the_X, the_Y);
+                frame.setVisible(true);
+            }
+        });
 
-        HDFView frame = new HDFView(rootDir, flist, W, H, X, Y);
-        frame.setVisible(true);
         //try { loadExtModules(); } catch (Exception ex) {}
     }
 }
